<?php
/**
* Convert HTML ToC to Flare ToC.
* Your TOC can be an ordered, unordered, or data list.
* @param string $argv[1] File with the TOC list
*/
if ($argc != 2){ 
  echo "Incorrect number of parameters.";
  exit(1);
}
  
$source = $argv[1]; // file with the toc 
$filename = "myimport.fltoc";
$doc = new DOMDocument();
$doc->load($source);
$new_doc = new DOMDocument();
$new_doc->formatOutput = true;
makeRoot($new_doc);
$xpath = new DOMXPath($doc);
$ns = $doc->documentElement->namespaceURI;
if($ns) {
  //check for all list types
  $xpath->registerNamespace("ns", $ns);
  $elements = $xpath->query("//*[self::ns:ul or self::ns:ol or self::ns:dl]");
} else {
  $elements = $xpath->query("//*[self::ul or self::ol or self::dl]");
}
//only the first element is of interest
$node = $elements->item(0);
if(! $node) {
  exit("ToC element not found.");
}
createFlareXML($node, $new_doc, $new_doc->documentElement);
$new_doc->save($filename);
//end main

/**
* Create the root node of the Flare
* document.
* @param DOMDocument $new_doc The new TOC file
*/
function makeRoot($new_doc){
  //create document with CatapultToc root
  $root = $new_doc->createElement('CatapultToc');
  //create root node
  $root->setAttribute("Version","1");
  $new_doc->appendChild($root);
  return;
}

/**
* Convert to a Flare TOC. The list type of
* the HTML must be ul, ol or dl.
* Invoke recursively.
* @param DOMNode     $node The current HTML node
* @param DOMDocument $new_doc The Flare TOC XML file
* @param DOMNode     $parent Where to attach new nodes
*/
function createFlareXML($node, $new_doc, $parent){ 
  foreach ($node->childNodes as $n) {
    $type = $n->nodeName;
    switch ($type) {
      case "dl": 
      case "ul":
      case "ol":
        //must be a sublevel so reset parent
        $p = $parent->lastChild;
        createFlareXML($n, $new_doc, $p);
        break;

      case "a": 
        //where all the info is
        $href = $n->getAttribute("href");
        $title =  trim($n->nodeValue);
        $entry = $new_doc->createElement('TocEntry');
        //set attributes
        $entry->setAttribute("Title", $title ); 
        //use getcwd() for current directory
        $dir = basename(getcwd()); 
        $entry->setAttribute("Link", "/Content/$dir/" . $href );
        if($parent === $new_doc->documentElement) { 
          $entry->setAttribute("BreakType", "chapter" );
        }
        //append new node
        $parent->appendChild($entry);
        break;

      default: //just call again for other tags 
        if($n->hasChildNodes()){
          createFlareXML($n, $new_doc, $parent);
        }
    }
  }
}
?>