<?php
/**
* Replace hrefs with xrefs. This script
* converts any internal hrefs:
* <a href="page">"Text"</a>
*      to:
* <MadCap:xref href="page">"Text"</MadCap:xref>
* © 2017 Moneris Solutions Corporation, CC-BY-NC -SA 4.0
*/
$schemes = Array ("http", "https", "ftp", "mailto", "file", "javascript"); 
//find all HTML files in the current directory
foreach (glob("./*.{xhtml,html,htm}", GLOB_BRACE) as $file){
  $changed = false;
  $d = new DOMDocument();
  $d->formatOutput = true;
  $d->load($file);
  $xpath = new DOMXPath($d);
  //get namespace
  $ns = $d->documentElement->namespaceURI;
  if($ns) {
    $xpath->registerNamespace("ns", $ns);
    //find all
    $elements = $xpath->query("//ns:a[@href]");
  } else {
    $elements = $xpath->query("//a[@href]");
  }
  if($elements->item(0)){
    foreach ($elements as $node) {
      $href = $node->getAttribute("href");
      //ignore external links
      $scheme = parse_url($href, PHP_URL_SCHEME);
      //exclude any anchors as well since they won't
      //necessarily work
      if (!in_array($scheme, $schemes) ) { 
        /*if (!in_array($scheme, $schemes) &&
          (strpos($href, "#") === false) ) {*/
        if($node->textContent != "") { 
          $xref = $d->createElement('MadCap:xref', $node->nodeValue); 
          //set attribute
          $xref->setAttribute("href", $href);
          $parent = $node->parentNode;
          $parent->replaceChild($xref, $node);
          $changed = true;
        }
      }
    }
    if ($changed){
      $d->save($file);
    }
  }
}
?>
